@@ -9,3 +9,7 @@ class NotSupported(SqlIntuitiveException):
 
     def __str__(self):
         return f"{self.featureName} is not supported in {self.dbSystemName}."
+
+class CursorIsNone(SqlIntuitiveException):
+    def __str__(self):
+        return "Cursor was never created."
